import { writable, readable } from "svelte/store";
import Data from "../data.json";
import { Question } from "./data";

const runsShould = 3;

class QuestionManager {
    activeQuestion = writable<{
        correct: () => void;
        wrong: () => void;
        question: Question
    }>(undefined);


    progress = writable(0);

    private availableQuestions: {
        question: Question,
        level: number
    }[];

    constructor() {
        this.availableQuestions = Data.questions.map(question => {
            return {
                question,
                level: Number(localStorage.getItem(question.id)) || 0
            }
        })

        this.getNewActive();
    }

    getNewActive() {
        let progress = 0;
        let highest = -1;
        this.availableQuestions.forEach(question => {
            const runs = question.level;
            if (runs > highest)
                highest = runs;

            progress += runs > runsShould ? runsShould : runs;
        })

        this.progress.set((progress / (this.availableQuestions.length * runsShould)) * 100);

        let options = this.availableQuestions.filter(question => question.level < highest);
        if (options.length <= 0)
            options = this.availableQuestions;

        let idx = Math.floor(Math.random() * options.length);
        let randomItem = options[idx];
        console.log("Setting question", randomItem);
        this.activeQuestion.set({
            question: randomItem.question,
            correct: () => {
                randomItem.level++;
                localStorage.setItem(randomItem.question.id, randomItem.level.toString());
                this.getNewActive();
            },
            wrong: () => {
                this.getNewActive();
            }
        })
    }
}

export default new QuestionManager();

import Theme from "./helper/theme";

export enum DeviceTypes {
    MOBILE,
    DESKTOP
}

const deviceTypeQuery = window.matchMedia("(min-width: 60rem)");

export const DeviceType = writable<DeviceTypes>(Number(deviceTypeQuery.matches));

const onChange = (ev: MediaQueryListEvent) => DeviceType.set(Number(ev.matches));
deviceTypeQuery.addListener(onChange);

export const IsDark = readable(Theme.isDark(), set => {
    set(Theme.isDark());
    const onChange = (val) => set(val);
    Theme.isDarkObservable.subscribe(onChange)
    return () => Theme.isDarkObservable.unsubscribe(onChange);
})

export { ModalStore } from "./modals";